@@ -7,6 +7,8 @@
 
 import pandas as pd
 import requests
+import ssl
+ssl._create_default_https_context = ssl._create_unverified_context
 
 
 def franchise_china():
